@@ -6,7 +6,8 @@ source /venv/bin/activate
 
 touch requirements_dev.txt
 pip install -r requirements_dev.txt -e .[dev]
-pip freeze --exclude-editable > dist/requirements_dev.txt
+mkdir -p lockfiles
+pip freeze --exclude-editable > lockfiles/requirements_dev.txt
 
 pipdeptree
 
